@@ -13,7 +13,7 @@ QString UserAgentChanger::getCurrentAgent()
     userjs.close();
     if (userjs.error() != QFile::NoError)
     {
-        emit error("input/output error");
+        emit error(userjs.errorString());
         return "";
     }
     return uadata.section('\"', 3, 3);
@@ -32,7 +32,7 @@ void UserAgentChanger::setCurrentAgent(QString agent)
 
     if (userjs.error() != QFile::NoError)
     {
-        emit error("input/output error");
+        emit error(userjs.errorString());
         return;
     }
     restartBrowserUI();
